@@ -12,7 +12,10 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from typing import Any, Dict, IO, Mapping, Optional, Union
+import os
+from pathlib import Path
+from typing import Any, Dict, Optional, Union
+from urllib.parse import urlparse
 
 import yaml
 from pyspark.sql import SparkSession
@@ -35,8 +38,8 @@ class FileModelSpec(ModelSpec):
 
     Parameters
     ----------
-    spec : str, bytes, dict or file object
-        String content of the serialized spec, or a dict
+    spec_uri : str or Path
+        Spec file URI
     options : Dict[str, Any], optional
         Additionally options. If the same option exists in spec already,
         it will be overridden.
@@ -46,12 +49,13 @@ class FileModelSpec(ModelSpec):
 
     def __init__(
         self,
-        spec: Union[bytes, str, IO, Dict[str, Any]],
+        spec_uri: Union[str, Path],
         options: Optional[Dict[str, Any]] = None,
         validate: bool = True,
     ):
-        if not isinstance(spec, Mapping):
-            spec = yaml.load(spec, Loader=yaml.FullLoader)
+        with open_uri(spec_uri) as fobj:
+            spec = yaml.load(fobj, Loader=yaml.FullLoader)
+        self.base_dir = os.path.dirname(spec_uri)
         spec.setdefault("options", {})
         if options:
             spec["options"].update(options)
@@ -61,14 +65,23 @@ class FileModelSpec(ModelSpec):
         if self.flavor == "pytorch":
             from rikai.spark.sql.codegen.pytorch import load_model_from_uri
 
-            return load_model_from_uri(self.uri)
+            return load_model_from_uri(self.model_uri)
         else:
             raise SpecError("Unsupported flavor {}".format(self.flavor))
 
+    @property
+    def model_uri(self):
+        """Absolute model URI."""
+        origin_uri = super().model_uri
+        parsed = urlparse(origin_uri)
+        if parsed.scheme or os.path.isabs(origin_uri):
+            return origin_uri
+        return os.path.join(self.base_dir, origin_uri)
+
 
 def codegen_from_yaml(
     spark: SparkSession,
-    uri: str,
+    spec_uri: str,
     name: Optional[str] = None,
     options: Optional[Dict[str, str]] = None,
 ) -> str:
@@ -78,7 +91,7 @@ def codegen_from_yaml(
     ----------
     spark : SparkSession
         A live spark session
-    uri : str
+    spec_uri : str
         the model spec URI
     name : model name
         The name of the model.
@@ -90,8 +103,7 @@ def codegen_from_yaml(
     str
         Spark UDF function name for the generated data.
     """
-    with open_uri(uri) as fobj:
-        spec = FileModelSpec(fobj, options=options)
+    spec = FileModelSpec(spec_uri, options=options)
     udf = udf_from_spec(spec)
     return register_udf(spark, udf, name)
 
@@ -106,7 +118,10 @@ class FileSystemRegistry(Registry):
     def __repr__(self):
         return "FileSystemRegistry"
 
-    def resolve(self, uri: str, name: str, options: Dict[str, str]):
+    def resolve(self, spec):
+        name = spec.getName()
+        uri = spec.getUri()
+        options = spec.getOptions()
         logger.info(f"Resolving model {name} from {uri}")
         if uri.endswith(".yml") or uri.endswith(".yaml"):
             func_name = codegen_from_yaml(self._spark, uri, name, options)
