@@ -14,6 +14,7 @@
 """Custom Mlflow model logger to make sure models have the right logging for
 Rikai SQL ML
 """
+import warnings
 from typing import Any, Optional
 
 CONF_MLFLOW_TRACKING_URI = "rikai.sql.ml.registry.mlflow.tracking_uri"
@@ -105,7 +106,7 @@ class MlflowLogger:
 
         # no need to set the tracking uri here since this is intended to be
         # called inside the training loop within mlflow.start_run
-        getattr(mlflow, flavor).log_model(
+        getattr(mlflow, self.flavor).log_model(
             model,
             artifact_path,
             registered_model_name=registered_model_name,
@@ -119,9 +120,16 @@ class MlflowLogger:
             CONF_MLFLOW_POST_PROCESSING: post_processing,
             CONF_MLFLOW_ARTIFACT_PATH: artifact_path,
         }
+        for k in (CONF_MLFLOW_PRE_PROCESSING, CONF_MLFLOW_POST_PROCESSING):
+            if not tags[k]:
+                del tags[k]
+                warnings.warn(
+                    f"value of {k} is None or empty and "
+                    "will not be populated to MLflow"
+                )
         mlflow.set_tags(tags)
 
 
-KNOWN_FLAVORS = ["pytorch"]
+KNOWN_FLAVORS = ["pytorch", "sklearn"]
 for flavor in KNOWN_FLAVORS:
     globals()[flavor] = MlflowLogger(flavor)
