@@ -123,6 +123,13 @@ class MlflowModelSpec(ModelSpec):
                 "post": conf.get(CONF_MLFLOW_POST_PROCESSING, None),
             },
         }
+
+        # remove none value of pre/post processing
+        if not spec["transforms"]["pre"]:
+            del spec["transforms"]["pre"]
+        if not spec["transforms"]["post"]:
+            del spec["transforms"]["post"]
+
         # options
         for key, value in conf.items():
             key = key.lower().strip()
@@ -215,6 +222,11 @@ class MlflowRegistry(Registry):
         uri = raw_spec.getUri()
         logger.info(f"Resolving model {name} from {uri}")
         parsed = urlparse(uri)
+        if parsed.netloc:
+            raise ValueError(
+                "URI with 2 forward slashes is not supported, "
+                "try URI with 1 slash instead"
+            )
         if not parsed.scheme:
             raise ValueError("Scheme must be mlflow. How did you get here?")
         parts = parsed.path.strip("/").split("/", 1)
@@ -242,8 +254,8 @@ class MlflowRegistry(Registry):
             (CONF_MLFLOW_OUTPUT_SCHEMA, spec.getSchema()),
         ]
         tags = {k: v for k, v in from_spec if v}
-        tags.update(run.data.tags)
-        return tags
+        # PEP 448 syntax, right-to-left priority order
+        return {**run.data.tags, **tags}
 
     def get_options(self, spec, run):
         options = run.data.params
