@@ -17,7 +17,7 @@ from abc import ABC, abstractmethod
 
 import cv2
 
-from rikai.mixin import Displayable
+from rikai.mixin import Displayable, ToDict
 from rikai.spark.types import SegmentType, VideoStreamType, YouTubeVideoType
 
 __all__ = [
@@ -145,7 +145,7 @@ def getworst(v_pafy, preftype="any", ftypestrict=True, vidonly=False):
     return r
 
 
-class VideoStream(Displayable):
+class VideoStream(Displayable, ToDict):
     """Represents a particular video stream at a given uri"""
 
     __UDT__ = VideoStreamType()
@@ -189,6 +189,9 @@ class VideoStream(Displayable):
         for frame in SingleFrameSampler(self):
             yield frame
 
+    def to_dict(self) -> dict:
+        return {"uri": self.uri}
+
 
 class Segment:
     """A video segment bounded by frame numbers"""
