@@ -18,6 +18,7 @@
 
 from __future__ import annotations
 
+import base64
 from io import BytesIO, IOBase
 from pathlib import Path
 from tempfile import NamedTemporaryFile
@@ -31,15 +32,15 @@ from PIL import Image as PILImage
 # Rikai
 from rikai.conf import CONF_RIKAI_IMAGE_DEFAULT_FORMAT, options
 from rikai.internal.uri_utils import normalize_uri
-from rikai.io import copy
-from rikai.mixin import Asset, Displayable, ToNumpy, ToPIL
+from rikai.io import copy, open_output_stream
+from rikai.mixin import Asset, Displayable, ToDict, ToNumpy, ToPIL
 from rikai.spark.types import ImageType
 from rikai.types.geometry import Box2d
 
 __all__ = ["Image"]
 
 
-class Image(ToNumpy, ToPIL, Asset, Displayable):
+class Image(ToNumpy, ToPIL, Asset, Displayable, ToDict):
     """An external Image Asset.
 
     It contains a reference URI to an image stored on the remote system.
@@ -160,6 +161,8 @@ class Image(ToNumpy, ToPIL, Asset, Displayable):
             return Image(fobj.read(), **kwargs)
 
     def __repr__(self) -> str:
+        if self.is_embedded:
+            return "Image(<embedded>)"
         return f"Image(uri={self.uri})"
 
     def _repr_html_(self):
@@ -198,6 +201,32 @@ class Image(ToNumpy, ToPIL, Asset, Displayable):
         with self.to_pil() as pil_img:
             return np.asarray(pil_img)
 
+    def to_dict(self) -> dict:
+        if self.is_embedded:
+            return {"data": base64.b64encode(self.data).decode("ascii")}
+        return {"uri": self.uri}
+
+    def save(self, uri: Union[str, Path]) -> Image:
+        """Save the image into a file, specified by the file path or URI.
+
+        Parameters
+        ----------
+        uri : str or Path
+            The external URI to store the image to.
+
+        Returns
+        -------
+        :py:class:`Image`
+            A new image with the new URI / path
+        """
+        uri = str(uri)
+        if self.is_embedded:
+            with open_output_stream(str(uri)) as fobj:
+                fobj.write(self.data)
+        else:
+            copy(self.uri, uri)
+        return Image(uri)
+
     def crop(
         self, box: Union[Box2d, List[Box2d]], format: Optional[str] = None
     ) -> Union[Image, List[Image]]:
